@@ -16,7 +16,7 @@ class TESTING_FRAMEWORK(Enum):
     RERAN = "RERAN"
     ESPRESSO = "Espresso"
     ROBOTIUM = "Robotium"
-    APP_CRAWLER = "APP_CRAWLER"
+    APP_CRAWLER = "Crawler"
     DROIDBOT = "Droidbot"
     OTHER = "Other"
 
@@ -26,10 +26,12 @@ class PROFILER(Enum):
     PETRA = 'Petra'
     MONSOON = 'Monsoon'
     MANAFA = "E-manafa"
+    NONE = "None"
 
 class INSTRUMENTER(Enum):
     JINST = 'JInst'
     HUNTER = 'Hunter'
+    NONE = "None"
 
 class TESTING_APPROACH(Enum):
     WHITEBOX = "WhiteBox"
