@@ -9,7 +9,7 @@ from textops import cat, grep, cut, sed, echo, grepv
 from anadroid.application.Application import App
 from anadroid.application.ProjectModule import ProjectModule
 from anadroid.build.versionUpgrader import DefaultSemanticVersion
-from anadroid.utils.Utils import execute_shell_command, mega_find, get_results_dir
+from anadroid.utils.Utils import execute_shell_command, mega_find, get_results_dir, extract_version_from_apk
 
 RESULTS_DIR = get_results_dir()
 
@@ -52,7 +52,7 @@ class Project(object):
             shutil.rmtree(t)
 
 class AndroidProject(Project):
-    def __init__(self, projname, projdir,results_dir=RESULTS_DIR):
+    def __init__(self, projname, projdir,results_dir=RESULTS_DIR, clean_instrumentations=False):
         super(AndroidProject, self).__init__(projname=projname, projdir=projdir, results_dir=results_dir)
         self.root_build_file = self.get_root_build_file()
         self.main_manif_file = self.get_main_manif_file()
@@ -63,6 +63,8 @@ class AndroidProject(Project):
         super().init_results_dir(self.app_id)
         self.proj_version = DefaultSemanticVersion("0.0")
         self.apks = {'Test': [], 'Debug': [], 'Release': [], 'Custom': []}
+        if clean_instrumentations:
+            self.clean_trasformations()
 
     def __gen_proj_id(self):
         pkg_line = str(cat(self.main_manif_file) | grep("package=\"[^\"]"))
@@ -113,12 +115,12 @@ class AndroidProject(Project):
         for mod_n in modules:
             mod_name = mod_n.strip()
             res = execute_shell_command("find %s -maxdepth 1 -type d -name \"%s\"" % (self.proj_dir, mod_name))
-            if res.validate():
+            if res.validate() and res.output.strip() != "":
                 self.modules[mod_name] = ProjectModule(mod_name, res.output.strip())
                 #print(self.modules[mod_name].module_type)
 
     def get_gradle_plugin(self):
-        gradle_plugin_version = str(cat(self.root_build_file) | grep("com.android.tools.build") | sed("classpath|com.android.tools.build:gradle:|\"", "")).strip()
+        gradle_plugin_version = str(cat(self.root_build_file) | grep("com.android.tools.build") | sed("classpath|com.android.tools.build:gradle:|\"", "")).strip().replace("'","")
         return gradle_plugin_version
 
     def create_inner_folder(self, name="libs"):
@@ -147,6 +149,7 @@ class AndroidProject(Project):
     def set_version(self, build_type):
         apks = self.get_apks(build_type)
         if len(apks) == 0:
-            return
-        ref_apk = apks[0]
-        #apk_version =
+            self.proj_version = DefaultSemanticVersion("0.0")
+        ref_apk = apks[0] # assuming first since main apk is build before building tests apk
+        v = extract_version_from_apk(ref_apk)
+        self.proj_version = DefaultSemanticVersion(v)
