@@ -1,24 +1,33 @@
 from subprocess import Popen, PIPE, TimeoutExpired
 
-from manafa.utils.Logger import log, LogSeverity
+from manafa.utils.Logger import LogSeverity
+from manafa.utils.Logger import log as logm
+
 from textops import find
 import os
 
-PYNADROID_KEYSTORE_PATH = "resources/keys/pynadroid-releases.keystore"
-KEYSTORE_PASSWORD = "pynadroid"
-
-
 def get_reference_dir(packname):
     base_dir = os.path.dirname(os.path.dirname(os.path.dirname(__file__)))
     # base_dir = sysconfig.get_path("purelib")
     return os.path.join(base_dir, packname)
 
-
 def get_resources_dir(packname="anadroid", default_res_dir="resources"):
     ref_dir = get_reference_dir(packname)
     return os.path.join(ref_dir, default_res_dir)
 
 
+def get_keystore_path():
+    return os.path.join(get_resources_dir(),"keys","pynadroid-releases.keystore")
+
+
+def get_keystore_pwd():
+    return "pynadroid"
+
+
+def get_general_config_dir(packname="anadroid", default_res_dir="resources"):
+    return os.path.join(get_resources_dir(packname, default_res_dir), "config")
+
+
 def get_pack_dir(packname="anadroid"):
     return get_reference_dir(packname)
 
@@ -29,37 +38,45 @@ def get_results_dir(default_results_dir="anadroid_results"):
         os.mkdir(ref_dir)
     return ref_dir
 
+
 def extract_pkg_name_from_apk(apkpath):
     res = execute_shell_command("find $ANDROID_HOME/build-tools/ -name \"aapt\" | head -1")
     res.validate(Exception("Unable to find aapt executable"))
     aapt_executable = res.output.strip()
     res = execute_shell_command(f"{aapt_executable}  dump badging {apkpath} | grep 'package: name='")
     res.validate(Exception("error while executing aapt"))
-    pkg_name = res.output.split(" ")[1].replace("name=","").replace("'","")
+    pkg_name = res.output.split(" ")[1].replace("name=", "").replace("'", "")
     return pkg_name
 
 
-
+def extract_version_from_apk(apkpath):
+    res = execute_shell_command("find $ANDROID_HOME/build-tools/ -name \"aapt\" | head -1")
+    res.validate(Exception("Unable to find aapt executable"))
+    aapt_executable = res.output.strip()
+    res = execute_shell_command(f"{aapt_executable}  dump badging {apkpath} | grep 'versionName='")
+    res.validate(Exception("error while executing aapt"))
+    return res.output.split(" ")[3].replace("versionName=", "").replace("'", "")
 
 def get_date_str():
     res = execute_shell_command("date +\"%d_%m_%y_%H_%M_%S\"")
     if res.validate(Exception("Unable to get date")):
         return res.output.strip()
 
+
 def get_apksigner_bin():
     res = execute_shell_command("find $ANDROID_HOME/build-tools/ -name \"apksigner\"")
     if res.validate(Exception("No apksigner found")):
         return res.output.split()[0]
-    return "/Users/ruirua/Library/Android/sdk/build-tools/30.0.3/apksigner"
+    return "$ANDROID_HOME/build-tools/30.0.3/apksigner"
 
 def sign_apk(apk_path):
        # deprecated after api 26: "jarsigner -verbose -sigalg SHA2-256withRSA -digestalg SHA2-256  -keystore {keystore} {apk_path} {key_alias} <<< \"{passwd}\"".format(keystore=PYNADROID_KEYSTORE_PATH,apk_path=apk_path,key_alias=KEY_ALIAS,passwd=PASSWORD)
        signer_bin = get_apksigner_bin()
        cmd = """{signer_bin} sign --ks {keystore_path} {apk_path} <<< {passwd}""".format(
            signer_bin=signer_bin,
-           keystore_path=PYNADROID_KEYSTORE_PATH,
+           keystore_path=get_keystore_path(),
            apk_path=apk_path,
-           passwd=KEYSTORE_PASSWORD
+           passwd=get_keystore_pwd()
        )
        res = execute_shell_command(cmd)
        res.validate(Exception("error signing apk " + apk_path))
@@ -104,7 +121,7 @@ class COMMAND_RESULT(object):
                     print(self)
                     raise e
                 else:
-                    log(e, log_sev=LogSeverity.ERROR)
+                    loge(e)
                     return False
             else:
                 #print(self)
@@ -121,4 +138,25 @@ class COMMAND_RESULT(object):
 
 
 def log_to_file(content, filename):
-    open(filename, 'w').write(content)
+    with open(filename, 'a+') as u:
+        u.write(content + "\n")
+
+
+def logi(message):
+    logm(message, log_sev=LogSeverity.INFO)
+
+
+def logw(message):
+    logm(message, log_sev=LogSeverity.WARNING)
+
+
+def loge(message):
+    logm(message, log_sev=LogSeverity.ERROR)
+
+
+def logf(message):
+    logm(message, log_sev=LogSeverity.FATAL)
+
+
+def logs(message):
+    logm(message, log_sev=LogSeverity.SUCCESS)
\ No newline at end of file
